You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2005/12/13 07:37:18 UTC

svn commit: r356490 [1/2] - in /webservices/axis2/trunk/c: include/ modules/core/context/src/ modules/core/description/src/ modules/core/engine/src/ modules/core/phaseresolver/src/

Author: damitha
Date: Mon Dec 12 22:36:46 2005
New Revision: 356490

URL: http://svn.apache.org/viewcvs?rev=356490&view=rev
Log:
engine_config renamed to conf

Added:
    webservices/axis2/trunk/c/include/axis2_conf.h
      - copied, changed from r356488, webservices/axis2/trunk/c/include/axis2_engine_config.h
Removed:
    webservices/axis2/trunk/c/include/axis2_engine_config.h
Modified:
    webservices/axis2/trunk/c/include/axis2_conf_ctx.h
    webservices/axis2/trunk/c/include/axis2_module_desc.h
    webservices/axis2/trunk/c/include/axis2_msg_ctx.h
    webservices/axis2/trunk/c/include/axis2_op_ctx.h
    webservices/axis2/trunk/c/include/axis2_phase_resolver.h
    webservices/axis2/trunk/c/include/axis2_svc.h
    webservices/axis2/trunk/c/include/axis2_svc_ctx.h
    webservices/axis2/trunk/c/include/axis2_svc_grp.h
    webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h
    webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c
    webservices/axis2/trunk/c/modules/core/description/src/module_desc.c
    webservices/axis2/trunk/c/modules/core/description/src/svc.c
    webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c
    webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c
    webservices/axis2/trunk/c/modules/core/engine/src/engine.c
    webservices/axis2/trunk/c/modules/core/engine/src/engine_config.c
    webservices/axis2/trunk/c/modules/core/engine/src/req_uri_disp.c
    webservices/axis2/trunk/c/modules/core/phaseresolver/src/phase_resolver.c

Copied: webservices/axis2/trunk/c/include/axis2_conf.h (from r356488, webservices/axis2/trunk/c/include/axis2_engine_config.h)
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_conf.h?p2=webservices/axis2/trunk/c/include/axis2_conf.h&p1=webservices/axis2/trunk/c/include/axis2_engine_config.h&r1=356488&r2=356490&rev=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_engine_config.h (original)
+++ webservices/axis2/trunk/c/include/axis2_conf.h Mon Dec 12 22:36:46 2005
@@ -46,8 +46,8 @@
 struct axis2_phases_info;    
 struct axis2_transport_in_desc *transports_in;
 struct axis2_transport_out_desc *transports_out;
-typedef struct axis2_engine_config_ops axis2_engine_config_ops_t;
-typedef struct axis2_engine_config axis2_engine_config_t;
+typedef struct axis2_conf_ops axis2_conf_ops_t;
+typedef struct axis2_conf axis2_conf_t;
     
 struct axis2_svc_grp;
 struct axis2_svc;
@@ -57,62 +57,62 @@
  * @brief Engine Configuration ops struct
  * Encapsulator struct for ops of axis2_config
  */
-struct axis2_engine_config_ops
+struct axis2_conf_ops
 {
 	axis2_status_t (AXIS2_CALL *
-    free) (axis2_engine_config_t *engine_config, 
+    free) (axis2_conf_t *conf, 
            axis2_env_t **env);
     
 	axis2_status_t (AXIS2_CALL *
-    add_svc_grp) (axis2_engine_config_t *engine_config, 
+    add_svc_grp) (axis2_conf_t *conf, 
                     axis2_env_t **env, 
                     struct axis2_svc_grp *svc_grp);
     
 	struct axis2_svc_grp *(AXIS2_CALL *
-    get_svc_grp) (  axis2_engine_config_t *engine_config, 
+    get_svc_grp) (  axis2_conf_t *conf, 
                     axis2_env_t **env, 
                     axis2_char_t *svc_grp_name);
  
     axis2_hash_t * (AXIS2_CALL *
-    get_svc_grps) (axis2_engine_config_t *engine_config, 
+    get_svc_grps) (axis2_conf_t *conf, 
                    axis2_env_t **env);
     
 	axis2_status_t (AXIS2_CALL *
-    add_svc) (axis2_engine_config_t *engine_config, 
+    add_svc) (axis2_conf_t *conf, 
                 axis2_env_t **env, 
                 struct axis2_svc* svc);
     
 	struct axis2_svc *(AXIS2_CALL *
-    get_svc) (axis2_engine_config_t *engine_config, 
+    get_svc) (axis2_conf_t *conf, 
                 axis2_env_t **env, 
                 axis2_char_t* svc_name);
     
 	axis2_status_t (AXIS2_CALL *
-    remove_svc) (axis2_engine_config_t *engine_config, 
+    remove_svc) (axis2_conf_t *conf, 
                     axis2_env_t **env, 
                     const axis2_char_t *name);
     
     axis2_status_t (AXIS2_CALL *
-    add_param) (axis2_engine_config_t *engine_config, 
+    add_param) (axis2_conf_t *conf, 
                     axis2_env_t **env,
                     axis2_param_t *param);
 
 	axis2_param_t *(AXIS2_CALL *
-    get_param) (axis2_engine_config_t *engine_config, 
+    get_param) (axis2_conf_t *conf, 
                 axis2_env_t **env,
                 const axis2_char_t *name);
 
 	axis2_array_list_t *(AXIS2_CALL *
-    get_params) (axis2_engine_config_t *engine_config, 
+    get_params) (axis2_conf_t *conf, 
                  axis2_env_t **env);
 	
 	axis2_bool_t (AXIS2_CALL *
-    is_param_locked) (axis2_engine_config_t *engine_config, 
+    is_param_locked) (axis2_conf_t *conf, 
                         axis2_env_t **env,
                         axis2_char_t *param_name);
                                                 
     struct axis2_transport_in_desc * (AXIS2_CALL *
-    get_transport_in)(axis2_engine_config_t *engine_config,
+    get_transport_in)(axis2_conf_t *conf,
                                             axis2_env_t **env,
                                             axis2_qname_t *qname);
     
@@ -123,12 +123,12 @@
      * @throws AxisFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_transport_in) (axis2_engine_config_t *engine_config,
+    add_transport_in) (axis2_conf_t *conf,
                         axis2_env_t **env,
                         struct axis2_transport_in_desc *transport);
     
     struct axis2_transport_out_desc * (AXIS2_CALL *
-    get_transport_out) (axis2_engine_config_t *engine_config,
+    get_transport_out) (axis2_conf_t *conf,
                         axis2_env_t **env,
                         axis2_qname_t *qname);
     
@@ -139,16 +139,16 @@
      * @throws AxisFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_transport_out) (axis2_engine_config_t *engine_config,
+    add_transport_out) (axis2_conf_t *conf,
                                             axis2_env_t **env,
                                             struct axis2_transport_out_desc *transport);
     
     axis2_hash_t * (AXIS2_CALL *
-    get_transports_in) (axis2_engine_config_t *engine_config,
+    get_transports_in) (axis2_conf_t *conf,
                                             axis2_env_t **env);
     
     axis2_hash_t * (AXIS2_CALL *
-    get_transports_out) (axis2_engine_config_t *engine_config,
+    get_transports_out) (axis2_conf_t *conf,
                                             axis2_env_t **env);
     /**
      * Method getModule
@@ -157,7 +157,7 @@
      * @return ModuleDescription
      */
     struct axis2_module_desc *(AXIS2_CALL *
-    get_module) (axis2_engine_config_t *engine_config,
+    get_module) (axis2_conf_t *conf,
                                             axis2_env_t **env,
                                             axis2_qname_t *qname);
     
@@ -167,16 +167,16 @@
      * @return  Collection
      */
     axis2_array_list_t * (AXIS2_CALL *
-    get_engaged_modules) (axis2_engine_config_t *engine_config,
+    get_engaged_modules) (axis2_conf_t *conf,
                                             axis2_env_t **env);
     
     axis2_array_list_t * (AXIS2_CALL *
     get_inphases_upto_and_including_post_dispatch) (
-                                                axis2_engine_config_t *engine_config,
+                                                axis2_conf_t *conf,
                                                 axis2_env_t **env);
     
     axis2_array_list_t * (AXIS2_CALL *
-    get_outflow) (axis2_engine_config_t *engine_config,
+    get_outflow) (axis2_conf_t *conf,
                                             axis2_env_t **env);
     
     
@@ -184,55 +184,55 @@
      * @return ArrayList
      */
     axis2_array_list_t * (AXIS2_CALL *
-    get_in_faultflow) (axis2_engine_config_t *engine_config,
+    get_in_faultflow) (axis2_conf_t *conf,
                                             axis2_env_t **env);
     
     /**
      * @return ArrayList
      */
     axis2_array_list_t * (AXIS2_CALL *
-    get_out_faultflow) (axis2_engine_config_t *engine_config,
+    get_out_faultflow) (axis2_conf_t *conf,
                                             axis2_env_t **env);
 
         axis2_hash_t *(AXIS2_CALL *
-    get_faulty_svcs) (axis2_engine_config_t *engine_config,
+    get_faulty_svcs) (axis2_conf_t *conf,
                                         axis2_env_t **env);
     
     axis2_hash_t *(AXIS2_CALL *
-    get_faulty_modules) (axis2_engine_config_t *engine_config,
+    get_faulty_modules) (axis2_conf_t *conf,
                                         axis2_env_t **env);
         
     /*to get all the services in the system */
     axis2_hash_t *(AXIS2_CALL *
-    get_svcs) (axis2_engine_config_t *engine_config,
+    get_svcs) (axis2_conf_t *conf,
                                     axis2_env_t **env);
     
     axis2_bool_t (AXIS2_CALL *
-    is_engaged) (axis2_engine_config_t *engine_config,
+    is_engaged) (axis2_conf_t *conf,
                                     axis2_env_t **env,
                                     axis2_qname_t *module_name);
     
     struct axis2_phases_info *(AXIS2_CALL *
-    get_phases_info) (axis2_engine_config_t *engine_config,
+    get_phases_info) (axis2_conf_t *conf,
                                         axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_phases_info) (axis2_engine_config_t *engine_config,
+    set_phases_info) (axis2_conf_t *conf,
                                         axis2_env_t **env,
                                         struct axis2_phases_info *phases_info);
     axis2_status_t (AXIS2_CALL *
-    add_msg_recv) (axis2_engine_config_t *engine_config,
+    add_msg_recv) (axis2_conf_t *conf,
                                         axis2_env_t **env,
                                         axis2_char_t *key,
                                         struct axis2_msg_recv *msg_recv);
     
     struct axis2_msg_recv *(AXIS2_CALL *
-    get_msg_recv) (axis2_engine_config_t *engine_config,
+    get_msg_recv) (axis2_conf_t *conf,
                                         axis2_env_t **env,
                                         axis2_char_t *key);
     
     axis2_status_t (AXIS2_CALL *
-    set_outphases) (axis2_engine_config_t *engine_config,
+    set_outphases) (axis2_conf_t *conf,
                                         axis2_env_t **env,
                                         axis2_array_list_t *outphases);
     
@@ -240,7 +240,7 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_in_faultphases) (axis2_engine_config_t *engine_config,
+    set_in_faultphases) (axis2_conf_t *conf,
                                             axis2_env_t **env,
                                             axis2_array_list_t *list);
     
@@ -248,7 +248,7 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_out_faultphases) (axis2_engine_config_t *engine_config,
+    set_out_faultphases) (axis2_conf_t *conf,
                                             axis2_env_t **env,
                                             axis2_array_list_t *list);
         
@@ -256,7 +256,7 @@
      * @return HashMap
      */
     axis2_hash_t *(AXIS2_CALL *
-    get_modules) (axis2_engine_config_t *engine_config,
+    get_modules) (axis2_conf_t *conf,
                                     axis2_env_t **env); 
     
     /**
@@ -265,7 +265,7 @@
      * @param module
      */
     axis2_status_t (AXIS2_CALL *
-    add_module) (axis2_engine_config_t *engine_config,
+    add_module) (axis2_conf_t *conf,
                                     axis2_env_t **env,
                                     struct axis2_module_desc *module);
                                                 
@@ -279,128 +279,128 @@
  * Service states kept in the <code>MessageContext</code>. Other runtime
  * artifacts does not keep states forward from the execution.
  */
-struct axis2_engine_config
+struct axis2_conf
 {
-	axis2_engine_config_ops_t *ops;
+	axis2_conf_ops_t *ops;
     axis2_param_container_t *param_container;
 };
 
 /** create Engine configuration struct
  * @return pointer to newly created engine configuration
  */
-axis2_engine_config_t * AXIS2_CALL 
-axis2_engine_config_create(axis2_env_t **env);
+axis2_conf_t * AXIS2_CALL 
+axis2_conf_create(axis2_env_t **env);
 
 /************************* Start of function macros	***************************/
 	
-#define AXIS2_ENGINE_CONFIG_FREE(engine_config, env) \
-		(engine_config->ops->free(engine_config, env))
+#define AXIS2_ENGINE_CONFIG_FREE(conf, env) \
+		(conf->ops->free(conf, env))
 	
-#define AXIS2_ENGINE_CONFIG_ADD_SVC_GRP(engine_config, env, svc_grp) \
-        (engine_config->ops->add_svc_grp (engine_config, env, svc_grp))
+#define AXIS2_ENGINE_CONFIG_ADD_SVC_GRP(conf, env, svc_grp) \
+        (conf->ops->add_svc_grp (conf, env, svc_grp))
 
-#define AXIS2_ENGINE_CONFIG_GET_SVC_GRP(engine_config, env, svc_grp_name) \
-        (engine_config->ops->get_svc_grp (engine_config, env, svc_grp_name))
+#define AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, svc_grp_name) \
+        (conf->ops->get_svc_grp (conf, env, svc_grp_name))
 
-#define AXIS2_ENGINE_CONFIG_GET_SVC_GRPS(engine_config, env) \
-        (engine_config->ops->get_svc_grps (engine_config, env))
+#define AXIS2_ENGINE_CONFIG_GET_SVC_GRPS(conf, env) \
+        (conf->ops->get_svc_grps (conf, env))
 
-#define AXIS2_ENGINE_CONFIG_ADD_SVC(engine_config, env, svc) \
-		(engine_config->ops->get_svc (engine_config, env, svc))
+#define AXIS2_ENGINE_CONFIG_ADD_SVC(conf, env, svc) \
+		(conf->ops->get_svc (conf, env, svc))
 		
-#define AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, svc_name) \
-		(engine_config->ops->get_svc (engine_config, env, svc_name))
+#define AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name) \
+		(conf->ops->get_svc (conf, env, svc_name))
 
-#define AXIS2_ENGINE_CONFIG_REMOVE_SVC(engine_config, env, svc_name) \
-		(engine_config->ops->remove_svc (engine_config, env, svc_name))
+#define AXIS2_ENGINE_CONFIG_REMOVE_SVC(conf, env, svc_name) \
+		(conf->ops->remove_svc (conf, env, svc_name))
         
-#define AXIS2_ENGINE_CONFIG_ADD_PARAM(engine_config, env, param) \
-        (engine_config->ops->add_param(engine_config , env, param))
+#define AXIS2_ENGINE_CONFIG_ADD_PARAM(conf, env, param) \
+        (conf->ops->add_param(conf , env, param))
 		
-#define AXIS2_ENGINE_CONFIG_GET_PARAM(engine_config, env, name) \
-        (engine_config->ops->get_param(engine_config , env, name))
+#define AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, name) \
+        (conf->ops->get_param(conf , env, name))
 		
-#define AXIS2_ENGINE_CONFIG_GET_PARAMS(engine_config, env) \
-        (engine_config->ops->get_params(engine_config , env))
+#define AXIS2_ENGINE_CONFIG_GET_PARAMS(conf, env) \
+        (conf->ops->get_params(conf , env))
 		
-#define AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(engine_config, env, param_name) \
-        (engine_config->ops->is_param_locked(engine_config, env, param_name))
+#define AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(conf, env, param_name) \
+        (conf->ops->is_param_locked(conf, env, param_name))
 
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(engine_config, env, qname) \
-        (engine_config->ops->get_transport_in(engine_config , env, qname))
+#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, qname) \
+        (conf->ops->get_transport_in(conf , env, qname))
 
-#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_IN(engine_config, env, transport) \
-        (engine_config->ops->add_transport_in(engine_config , env, transport))
+#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_IN(conf, env, transport) \
+        (conf->ops->add_transport_in(conf , env, transport))
 
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_OUT(engine_config, env, qname) \
-        (engine_config->ops->get_transport_out(engine_config , env, qname))
+#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_OUT(conf, env, qname) \
+        (conf->ops->get_transport_out(conf , env, qname))
 
-#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_OUT(engine_config, env, transport) \
-        (engine_config->ops->add_transport_out(engine_config , env, transport))
+#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_OUT(conf, env, transport) \
+        (conf->ops->add_transport_out(conf , env, transport))
  
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_IN(engine_config, env) \
-        (engine_config->ops->get_transports_in(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_IN(conf, env) \
+        (conf->ops->get_transports_in(conf , env)) 
  
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_OUT(engine_config, env) \
-        (engine_config->ops->get_transports_out(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_OUT(conf, env) \
+        (conf->ops->get_transports_out(conf , env)) 
  
-#define AXIS2_ENGINE_CONFIG_GET_MODULE(engine_config, env, qname) \
-        (engine_config->ops->get_module(engine_config , env, qname)) 
+#define AXIS2_ENGINE_CONFIG_GET_MODULE(conf, env, qname) \
+        (conf->ops->get_module(conf , env, qname)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_ENGAGED_MODULES(engine_config, env) \
-        (engine_config->ops->get_engaged_modules(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_ENGAGED_MODULES(conf, env) \
+        (conf->ops->get_engaged_modules(conf , env)) 
         
-#define AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(engine_config, env) \
-        (engine_config->ops->get_inphases_upto_and_including_post_dispatch(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(conf, env) \
+        (conf->ops->get_inphases_upto_and_including_post_dispatch(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_OUTFLOW(engine_config, env) \
-        (engine_config->ops->get_outflow(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_OUTFLOW(conf, env) \
+        (conf->ops->get_outflow(conf , env)) 
         
-#define AXIS2_ENGINE_CONFIG_GET_IN_FAULT_FLOW(engine_config, env) \
-        (engine_config->ops->get_in_faultflow(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_IN_FAULT_FLOW(conf, env) \
+        (conf->ops->get_in_faultflow(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_OUT_FAULT_FLOW(engine_config, env) \
-        (engine_config->ops->get_out_faultflow(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_OUT_FAULT_FLOW(conf, env) \
+        (conf->ops->get_out_faultflow(conf , env)) 
 
 
-#define AXIS2_ENGINE_CONFIG_GET_FAULTY_SVCS(engine_config, env) \
-        (engine_config->ops->get_faulty_svcs(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_FAULTY_SVCS(conf, env) \
+        (conf->ops->get_faulty_svcs(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_FAULTY_MODULES(engine_config, env) \
-        (engine_config->ops->get_faulty_modules(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_FAULTY_MODULES(conf, env) \
+        (conf->ops->get_faulty_modules(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_SVCS(engine_config, env) \
-        (engine_config->ops->get_svcs(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_SVCS(conf, env) \
+        (conf->ops->get_svcs(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_IS_ENGAGED(engine_config, env, module_name) \
-        (engine_config->ops->is_engaged(engine_config , env, module_name)) 
+#define AXIS2_ENGINE_CONFIG_IS_ENGAGED(conf, env, module_name) \
+        (conf->ops->is_engaged(conf , env, module_name)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_PHASESINFO(engine_config, env) \
-        (engine_config->ops->get_phases_info(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_PHASESINFO(conf, env) \
+        (conf->ops->get_phases_info(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_PHASESINFO(engine_config, env, phases_info) \
-        (engine_config->ops->set_phases_info(engine_config , env, phases_info)) 
+#define AXIS2_ENGINE_CONFIG_SET_PHASESINFO(conf, env, phases_info) \
+        (conf->ops->set_phases_info(conf , env, phases_info)) 
 
-#define AXIS2_ENGINE_CONFIG_ADD_MSG_RECV(engine_config, env, key, msg_recv) \
-        (engine_config->ops->add_msg_recv(engine_config , env, key, msg_recv)) 
+#define AXIS2_ENGINE_CONFIG_ADD_MSG_RECV(conf, env, key, msg_recv) \
+        (conf->ops->add_msg_recv(conf , env, key, msg_recv)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_MSG_RECV(engine_config, env, key) \
-        (engine_config->ops->get_msg_recv(engine_config , env, key)) 
+#define AXIS2_ENGINE_CONFIG_GET_MSG_RECV(conf, env, key) \
+        (conf->ops->get_msg_recv(conf , env, key)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_OUTPHASES(engine_config, env, outphases) \
-        (engine_config->ops->set_outphases(engine_config , env, outphases)) 
+#define AXIS2_ENGINE_CONFIG_SET_OUTPHASES(conf, env, outphases) \
+        (conf->ops->set_outphases(conf , env, outphases)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_IN_FAULTPHASES(engine_config, env, list) \
-        (engine_config->ops->set_in_faultphases(engine_config , env, list)) 
+#define AXIS2_ENGINE_CONFIG_SET_IN_FAULTPHASES(conf, env, list) \
+        (conf->ops->set_in_faultphases(conf , env, list)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_OUT_FAULTPHASES(engine_config, env, list) \
-        (engine_config->ops->set_out_faultphases(engine_config , env, list)) 
+#define AXIS2_ENGINE_CONFIG_SET_OUT_FAULTPHASES(conf, env, list) \
+        (conf->ops->set_out_faultphases(conf , env, list)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_MODULES(engine_config, env) \
-        (engine_config->ops->get_modules(engine_config , env)) 
+#define AXIS2_ENGINE_CONFIG_GET_MODULES(conf, env) \
+        (conf->ops->get_modules(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_ADD_MODULE(engine_config, env, module) \
-        (engine_config->ops->add_module(engine_config , env, module)) 
+#define AXIS2_ENGINE_CONFIG_ADD_MODULE(conf, env, module) \
+        (conf->ops->add_module(conf , env, module)) 
         
 /************************* End of function macros *****************************/
 

Modified: webservices/axis2/trunk/c/include/axis2_conf_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_conf_ctx.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_conf_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_conf_ctx.h Mon Dec 12 22:36:46 2005
@@ -41,7 +41,7 @@
     
 typedef struct axis2_conf_ctx_ops axis2_conf_ctx_ops_t;
 typedef struct axis2_conf_ctx axis2_conf_ctx_t; 
-struct axis2_engine_config;
+struct axis2_conf;
     
 /** 
  * @brief Message Context ops struct
@@ -52,16 +52,16 @@
     /**
      * @param configuration
      */
-    axis2_status_t (AXIS2_CALL *set_engine_config)(struct axis2_conf_ctx *conf_ctx, 
+    axis2_status_t (AXIS2_CALL *set_conf)(struct axis2_conf_ctx *conf_ctx, 
         axis2_env_t **env, 
-        struct axis2_engine_config *engine_config);
+        struct axis2_conf *conf);
     /**
      */
     axis2_ctx_t* (AXIS2_CALL *get_base)(struct axis2_conf_ctx *conf_ctx, 
         axis2_env_t **env);
     /**
      */
-    struct axis2_engine_config* (AXIS2_CALL *get_engine_config)(struct axis2_conf_ctx *conf_ctx, 
+    struct axis2_conf* (AXIS2_CALL *get_conf)(struct axis2_conf_ctx *conf_ctx, 
         axis2_env_t **env);
     axis2_hash_t* (AXIS2_CALL *get_op_ctx_map)(struct axis2_conf_ctx *conf_ctx, 
         axis2_env_t **env);
@@ -142,7 +142,7 @@
                                                             axis2_char_t *path);
     axis2_status_t (AXIS2_CALL *init)(struct axis2_conf_ctx *conf_ctx, 
                                                             axis2_env_t **env,
-                                                            struct axis2_engine_config *engine_config);
+                                                            struct axis2_conf *conf);
     axis2_status_t (AXIS2_CALL *free)(struct axis2_conf_ctx *conf_ctx, 
                                        axis2_env_t **env);
     /**
@@ -171,13 +171,13 @@
     axis2_conf_ctx_ops_t *ops;    
 };
 
-AXIS2_DECLARE(axis2_conf_ctx_t*) AXIS2_CALL create(axis2_env_t **env, struct axis2_engine_config *engine_config);
+AXIS2_DECLARE(axis2_conf_ctx_t*) AXIS2_CALL create(axis2_env_t **env, struct axis2_conf *conf);
     
 /************************** Start of function macros **************************/
 
-#define AXIS2_CONF_CTX_SET_ENGINE_CONFIG(conf_ctx, env, engine_config) ((conf_ctx)->ops->set_engine_config(conf_ctx, env, engine_config))
+#define AXIS2_CONF_CTX_SET_ENGINE_CONFIG(conf_ctx, env, conf) ((conf_ctx)->ops->set_conf(conf_ctx, env, conf))
 #define AXIS2_CONF_CTX_GET_BASE(conf_ctx, env) ((conf_ctx)->ops->get_base(conf_ctx, env))
-#define AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env) ((conf_ctx)->ops->get_engine_config(conf_ctx, env))
+#define AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env) ((conf_ctx)->ops->get_conf(conf_ctx, env))
 #define AXIS2_CONF_CTX_GET_OPERATION_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_op_ctx_map(conf_ctx, env))
 #define AXIS2_CONF_CTX_GET_SVC_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_svc_ctx_map(conf_ctx, env))
 #define AXIS2_CONF_CTX_GET_SVC_GRP_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_svc_grp_ctx_map(conf_ctx, env))
@@ -189,7 +189,7 @@
 #define AXIS2_CONF_CTX_GET_SVC_GRP_CTX(conf_ctx, env, svc_grp_id) ((conf_ctx)->ops->get_svc_grp_ctx(conf_ctx, env, svc_grp_id))
 #define AXIS2_CONF_CTX_GET_ROOT_DIR(conf_ctx, env) ((conf_ctx)->ops->get_root_dir(conf_ctx, env))
 #define AXIS2_CONF_CTX_SET_ROOT_DIR(conf_ctx, env, path) ((conf_ctx)->ops->set_root_dir(conf_ctx, env, path))
-#define AXIS2_CONF_CTX_INIT(conf_ctx, env, engine_config) ((conf_ctx)->ops->init(conf_ctx, env, engine_config))
+#define AXIS2_CONF_CTX_INIT(conf_ctx, env, conf) ((conf_ctx)->ops->init(conf_ctx, env, conf))
 #define AXIS2_CONF_CTX_FREE(conf_ctx, env) ((conf_ctx)->ops->free(conf_ctx, env))
 #define AXIS2_CONF_CTX_FILL_CXTS(conf_ctx, env, msg_ctx) ((conf_ctx)->ops->fill_ctxs(conf_ctx, env, msg_ctx))
 

Modified: webservices/axis2/trunk/c/include/axis2_module_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_module_desc.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_module_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_module_desc.h Mon Dec 12 22:36:46 2005
@@ -41,7 +41,7 @@
 #include <axis2_flow_container.h>
 #include <axis2_param.h>
 #include <axis2_op.h>
-#include <axis2_engine_config.h>
+#include <axis2_conf.h>
 
 
 #ifdef __cplusplus
@@ -50,7 +50,7 @@
 #endif
 
 struct axis2_op;
-struct axis2_engine_config;	
+struct axis2_conf;	
 typedef struct axis2_module_desc_ops axis2_module_desc_ops_t;
 typedef struct axis2_module_desc axis2_module_desc_t;	
 	
@@ -162,14 +162,14 @@
     get_ops ) (axis2_module_desc_t *module_desc,
                                         axis2_env_t **env);
     
-    struct axis2_engine_config * (AXIS2_CALL *
+    struct axis2_conf * (AXIS2_CALL *
     get_parent ) (axis2_module_desc_t *module_desc,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
     set_parent ) (axis2_module_desc_t *module_desc,
                                     axis2_env_t **env,
-                                    struct axis2_engine_config *parent);
+                                    struct axis2_conf *parent);
     
     /**
      * Add parameter

Modified: webservices/axis2/trunk/c/include/axis2_msg_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_msg_ctx.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_op_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_op_ctx.h Mon Dec 12 22:36:46 2005
@@ -70,7 +70,7 @@
     /**
      * The method is used to do the intialization of the axis2_op_ctx
      */
-    axis2_status_t (AXIS2_CALL *init)(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config);
+    axis2_status_t (AXIS2_CALL *init)(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_conf *conf);
     
     /**
      * @return Returns the op.
@@ -151,7 +151,7 @@
 /************************** Start of function macros **************************/
 #define OPERATION_CTX_GET_BASE(op_ctx, env) ((op_ctx)->ops->get_base(op_ctx, env))
 #define AXIS2_OPERATION_CTX_FREE(op_ctx, env) ((op_ctx)->ops->free(op_ctx, env))
-#define AXIS2_OPERATION_CTX_INIT(op_ctx, env, engine_config) ((op_ctx)->ops->init(op_ctx, env, engine_config))
+#define AXIS2_OPERATION_CTX_INIT(op_ctx, env, conf) ((op_ctx)->ops->init(op_ctx, env, conf))
 #define AXIS2_OPERATION_CTX_GET_OPERATION(op_ctx, env) ((op_ctx)->ops->get_op(op_ctx, env))
 #define AXIS2_OPERATION_CTX_GET_PARENT(op_ctx, env) ((op_ctx)->ops->get_parent(op_ctx, env))
 #define AXIS2_OPERATION_CTX_ADD_MSG_CTX(op_ctx, env, msg_ctx) ((op_ctx)->ops->add_msg_ctx(op_ctx, env, msg_ctx))

Modified: webservices/axis2/trunk/c/include/axis2_phase_resolver.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase_resolver.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase_resolver.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase_resolver.h Mon Dec 12 22:36:46 2005
@@ -51,7 +51,7 @@
 struct axis2_handler;
 struct axis2_phase_rule;
 struct axis2_svc;
-struct axis2_engine_config;
+struct axis2_conf;
 struct axis2_op; 
 struct axis2_phase_holder;    
 typedef struct axis2_phase_resolver axis2_phase_resolver_t;
@@ -164,7 +164,7 @@
  */
 AXIS2_DECLARE(axis2_phase_resolver_t *) 
 axis2_phase_resolver_create_with_config (axis2_env_t **env, 
-                                         struct axis2_engine_config *axis2_config);
+                                         struct axis2_conf *axis2_config);
 
 /**
  * Constructor PhaseResolver
@@ -174,7 +174,7 @@
  */
 AXIS2_DECLARE(axis2_phase_resolver_t *)
 axis2_phase_resolver_create_with_config_and_svc (axis2_env_t **env, 
-                                                struct axis2_engine_config *axis2_config,
+                                                struct axis2_conf *axis2_config,
                                                 struct axis2_svc *svc);
 
 /*************************** Function macros **********************************/

Modified: webservices/axis2/trunk/c/include/axis2_svc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc.h Mon Dec 12 22:36:46 2005
@@ -34,7 +34,7 @@
 #include <axis2.h>
 #include <axis2_phase_resolver.h>
 #include <axis2_module_desc.h>
-#include <axis2_engine_config.h>
+#include <axis2_conf.h>
 #include <axis2_wsdl_soap_op.h>
 #include <axis2_string.h>
 #include <axis2_wsdl_endpoint.h>
@@ -57,7 +57,7 @@
 struct axis2_wsdl_svc;
 struct axis2_wsdl_interface; 
 struct axis2_module_desc; 
-struct axis2_engine_config;
+struct axis2_conf;
 struct axis2_wsdl_soap_op;    
 typedef struct axis2_svc_ops axis2_svc_ops_t;   
 typedef struct axis2_svc axis2_svc_t;
@@ -148,7 +148,7 @@
     engage_module) (axis2_svc_t *svc,
                     axis2_env_t **env,
                     struct axis2_module_desc * moduleref,
-                    struct axis2_engine_config * axis2_config);
+                    struct axis2_conf * axis2_config);
     
     /**
      * To add a opeartion to a service if a module requird to do so
@@ -159,7 +159,7 @@
     add_module_ops) (axis2_svc_t *svc,
                                 axis2_env_t **env,
                                 struct axis2_module_desc * module_desc,
-                                struct axis2_engine_config * axis2_config); 
+                                struct axis2_conf * axis2_config); 
                                     
     axis2_status_t (AXIS2_CALL *
     add_to_engaged_module_list) (axis2_svc_t *svc,

Modified: webservices/axis2/trunk/c/include/axis2_svc_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_ctx.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_ctx.h Mon Dec 12 22:36:46 2005
@@ -58,7 +58,7 @@
      */
     axis2_status_t (AXIS2_CALL *init)(struct axis2_svc_ctx *svc_ctx, 
                                                 axis2_env_t **env,
-                                                axis2_engine_config_t *engine_config);
+                                                axis2_conf_t *conf);
     /**
      * @return Returns the svc_id.
      */
@@ -90,7 +90,7 @@
 #define AXIS2_SVC_CTX_GET_BASE(svc_ctx, env) ((svc_ctx)->ops->get_base(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_PARENT(svc_ctx, env) ((svc_ctx)->ops->get_parent(svc_ctx, env))
 #define AXIS2_SVC_CTX_FREE(svc_ctx, env) ((svc_ctx)->ops->free(svc_ctx, env))
-#define AXIS2_SVC_CTX_INIT(svc_ctx, env, engine_config) ((svc_ctx)->ops->init(svc_ctx, env, engine_config))
+#define AXIS2_SVC_CTX_INIT(svc_ctx, env, conf) ((svc_ctx)->ops->init(svc_ctx, env, conf))
 #define AXIS2_SVC_CTX_GET_SVC_ID(svc_ctx, env) ((svc_ctx)->ops->get_svc_id(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_SVC(svc_ctx, env) ((svc_ctx)->ops->get_svc(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_CONF_CTX(svc_ctx, env) ((svc_ctx)->ops->get_conf_ctx(svc_ctx, env))

Modified: webservices/axis2/trunk/c/include/axis2_svc_grp.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_grp.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_grp.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_grp.h Mon Dec 12 22:36:46 2005
@@ -123,14 +123,14 @@
                     axis2_env_t **env,
                     axis2_qname_t *module_qname);
 
-    struct axis2_engine_config * (AXIS2_CALL *
+    struct axis2_conf * (AXIS2_CALL *
     get_parent) (axis2_svc_grp_t *svc_grp,
                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
     set_parent) (axis2_svc_grp_t *svc_grp,
                     axis2_env_t **env,
-                    struct axis2_engine_config *parent);
+                    struct axis2_conf *parent);
                         
     axis2_status_t (AXIS2_CALL *
     engage_module_to_grp) (axis2_svc_grp_t *svc_grp,
@@ -141,14 +141,14 @@
     get_svc_grp_modules) (axis2_svc_grp_t *svc_grp,
                                         axis2_env_t **env);
     
-    struct axis2_engine_config *(AXIS2_CALL *
+    struct axis2_conf *(AXIS2_CALL *
     get_axis_desc) (axis2_svc_grp_t *svc_grp,
                                 axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
     set_axis_desc) (axis2_svc_grp_t *svc_grp,
                                 axis2_env_t **env,
-                                struct axis2_engine_config *axis2_desc);
+                                struct axis2_conf *axis2_desc);
     
     axis2_status_t (AXIS2_CALL *
     add_moduleref) (axis2_svc_grp_t *svc_grp,
@@ -181,12 +181,12 @@
 
 /** 
  * Creates service group struct
- * @param engine_config
+ * @param conf
  * @return pointer to newly created service group
  */
 axis2_svc_grp_t * AXIS2_CALL 
-axis2_svc_grp_create_with_engine_config (axis2_env_t **env,
-                                         struct axis2_engine_config *engine_config);
+axis2_svc_grp_create_with_conf (axis2_env_t **env,
+                                         struct axis2_conf *conf);
 
 /**************************** Start of function macros ************************/
 

Modified: webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h Mon Dec 12 22:36:46 2005
@@ -58,7 +58,7 @@
      */
     axis2_status_t (AXIS2_CALL *init)(struct axis2_svc_grp_ctx *svc_grp_ctx, 
                                         axis2_env_t **env,
-                                        axis2_engine_config_t *engine_config);
+                                        axis2_conf_t *conf);
     axis2_char_t* (AXIS2_CALL *get_id)(struct axis2_svc_grp_ctx *svc_grp_ctx, 
                             axis2_env_t **env);
     axis2_status_t (AXIS2_CALL *set_id)(struct axis2_svc_grp_ctx *svc_grp_ctx, 
@@ -98,7 +98,7 @@
 #define AXIS2_SVC_GRP_CTX_GET_BASE(svc_grp_ctx, env) ((svc_grp_ctx)->ops->get_base(svc_grp_ctx, env))
 #define AXIS2_SVC_GRP_CTX_GET_PARENT(svc_grp_ctx, env) ((svc_grp_ctx)->ops->get_parent(svc_grp_ctx, env))
 #define AXIS2_SVC_GRP_CTX_FREE(svc_grp_ctx, env) ((svc_grp_ctx)->ops->free(svc_grp_ctx, env))
-#define AXIS2_SVC_GRP_CTX_INIT(svc_grp_ctx, env, engine_config) ((svc_grp_ctx)->ops->init(svc_grp_ctx, env, engine_config))
+#define AXIS2_SVC_GRP_CTX_INIT(svc_grp_ctx, env, conf) ((svc_grp_ctx)->ops->init(svc_grp_ctx, env, conf))
 #define AXIS2_SVC_GRP_CTX_GET_ID(svc_grp_ctx, env) ((svc_grp_ctx)->ops->get_id(svc_grp_ctx, env))
 #define AXIS2_SVC_GRP_CTX_SET_ID(svc_grp_ctx, env, id) ((svc_grp_ctx)->ops->set_id(svc_grp_ctx, env, id))
 #define AXIS2_SVC_GRP_CTX_GET_SVC_CTX(svc_grp_ctx, env, svc_name) ((svc_grp_ctx)->ops->get_svc_ctx(svc_grp_ctx, env, svc_name))

Modified: webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c Mon Dec 12 22:36:46 2005
@@ -24,7 +24,7 @@
     /** base context struct */
     axis2_ctx_t *base;
     /** engine configuration */
-    axis2_engine_config_t *engine_config;
+    axis2_conf_t *conf;
     /** root dir */
     /* should be handled as a URL string ? */
     axis2_char_t *root_dir;
@@ -42,12 +42,12 @@
 /** Interface to implementation conversion macro */
 #define AXIS2_INTF_TO_IMPL(conf_ctx) ((axis2_conf_ctx_impl_t *)conf_ctx)
 
-axis2_status_t AXIS2_CALL axis2_conf_ctx_set_engine_config(struct axis2_conf_ctx *conf_ctx, 
+axis2_status_t AXIS2_CALL axis2_conf_ctx_set_conf(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env, 
-    axis2_engine_config_t *engine_config);
+    axis2_conf_t *conf);
 axis2_ctx_t* AXIS2_CALL axis2_conf_ctx_get_base(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
-axis2_engine_config_t* AXIS2_CALL axis2_conf_ctx_get_engine_config(struct axis2_conf_ctx *conf_ctx, 
+axis2_conf_t* AXIS2_CALL axis2_conf_ctx_get_conf(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
 axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx_map(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
@@ -83,7 +83,7 @@
                                                         axis2_char_t *path);
 axis2_status_t AXIS2_CALL axis2_conf_ctx_init(struct axis2_conf_ctx *conf_ctx, 
                                                         axis2_env_t **env,
-                                                        axis2_engine_config_t *engine_config);
+                                                        axis2_conf_t *conf);
 axis2_status_t AXIS2_CALL axis2_conf_ctx_free(struct axis2_conf_ctx *conf_ctx, 
                                    axis2_env_t **env);
 axis2_svc_grp_ctx_t* AXIS2_CALL axis2_conf_ctx_fill_ctxs(struct axis2_conf_ctx *conf_ctx, 
@@ -91,7 +91,7 @@
                                                axis2_msg_ctx_t *msg_ctx);
 
 
-axis2_conf_ctx_t* AXIS2_CALL axis2_conf_ctx_create(axis2_env_t **env, axis2_engine_config_t *engine_config) 
+axis2_conf_ctx_t* AXIS2_CALL axis2_conf_ctx_create(axis2_env_t **env, axis2_conf_t *conf) 
 {
     axis2_conf_ctx_impl_t *conf_ctx_impl = NULL;
     
@@ -106,14 +106,14 @@
     
     conf_ctx_impl->conf_ctx.ops = NULL;
     conf_ctx_impl->base = NULL;
-    conf_ctx_impl->engine_config = NULL;
+    conf_ctx_impl->conf = NULL;
     conf_ctx_impl->root_dir = NULL;
     conf_ctx_impl->op_ctx_map = NULL;
     conf_ctx_impl->svc_ctx_map = NULL;
     conf_ctx_impl->svc_grp_ctx_map = NULL;
     
-    if (engine_config)
-        conf_ctx_impl->engine_config = engine_config;
+    if (conf)
+        conf_ctx_impl->conf = conf;
     
     conf_ctx_impl->base = axis2_ctx_create(env);
     if (!(conf_ctx_impl->base))
@@ -154,9 +154,9 @@
 
     conf_ctx_impl->conf_ctx.ops->free = axis2_conf_ctx_free;
 
-    conf_ctx_impl->conf_ctx.ops->set_engine_config = axis2_conf_ctx_set_engine_config;
+    conf_ctx_impl->conf_ctx.ops->set_conf = axis2_conf_ctx_set_conf;
     conf_ctx_impl->conf_ctx.ops->get_base = axis2_conf_ctx_get_base;
-    conf_ctx_impl->conf_ctx.ops->get_engine_config = axis2_conf_ctx_get_engine_config;
+    conf_ctx_impl->conf_ctx.ops->get_conf = axis2_conf_ctx_get_conf;
     conf_ctx_impl->conf_ctx.ops->get_op_ctx_map = axis2_conf_ctx_get_op_ctx_map;
     conf_ctx_impl->conf_ctx.ops->get_svc_ctx_map = axis2_conf_ctx_get_svc_ctx_map;
     conf_ctx_impl->conf_ctx.ops->get_svc_grp_ctx_map = axis2_conf_ctx_get_svc_grp_ctx_map;
@@ -178,10 +178,10 @@
 /**
  * @param configuration
  */
-axis2_status_t AXIS2_CALL axis2_conf_ctx_set_engine_config(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env, axis2_engine_config_t *engine_config) 
+axis2_status_t AXIS2_CALL axis2_conf_ctx_set_conf(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env, axis2_conf_t *conf) 
 {
     AXIS2_FUNC_PARAM_CHECK(conf_ctx, env, AXIS2_FAILURE);
-    AXIS2_INTF_TO_IMPL(conf_ctx)->engine_config = engine_config; /* we just maitain a shalow copy here */
+    AXIS2_INTF_TO_IMPL(conf_ctx)->conf = conf; /* we just maitain a shalow copy here */
     return AXIS2_SUCCESS;
 }
 
@@ -195,10 +195,10 @@
 
 /**
  */
-axis2_engine_config_t* AXIS2_CALL axis2_conf_ctx_get_engine_config(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
+axis2_conf_t* AXIS2_CALL axis2_conf_ctx_get_conf(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(conf_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(conf_ctx)->engine_config;
+    return AXIS2_INTF_TO_IMPL(conf_ctx)->conf;
 }
 
 axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx_map(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
@@ -411,7 +411,7 @@
 
 axis2_status_t AXIS2_CALL axis2_conf_ctx_init(struct axis2_conf_ctx *conf_ctx, 
                                                         axis2_env_t **env,
-                                                        axis2_engine_config_t *engine_config)
+                                                        axis2_conf_t *conf)
 {
     axis2_conf_ctx_impl_t *conf_ctx_impl = NULL;
     axis2_hash_index_t *hi = NULL;
@@ -421,7 +421,7 @@
     
     conf_ctx_impl = AXIS2_INTF_TO_IMPL(conf_ctx);
 
-    conf_ctx_impl->engine_config = engine_config;
+    conf_ctx_impl->conf = conf;
     
     for (hi = axis2_hash_first (conf_ctx_impl->op_ctx_map, env);
              hi; hi = axis2_hash_next (env, hi))
@@ -430,7 +430,7 @@
         if (ctx)
         {
             axis2_op_ctx_t *op_ctx = (axis2_op_ctx_t*) ctx;
-            AXIS2_OPERATION_CTX_INIT(op_ctx, env, engine_config);
+            AXIS2_OPERATION_CTX_INIT(op_ctx, env, conf);
         }
     }
 
@@ -441,7 +441,7 @@
         if (ctx)
         {
             axis2_svc_ctx_t *svc_ctx = (axis2_svc_ctx_t*) ctx;
-            AXIS2_SVC_CTX_INIT(svc_ctx, env, engine_config);
+            AXIS2_SVC_CTX_INIT(svc_ctx, env, conf);
         }
     }
     
@@ -452,7 +452,7 @@
         if (ctx)
         {
             axis2_svc_grp_ctx_t *svc_grp_ctx = (axis2_svc_grp_ctx_t*) ctx;
-            AXIS2_SVC_GRP_CTX_INIT(svc_grp_ctx, env, engine_config);
+            AXIS2_SVC_GRP_CTX_INIT(svc_grp_ctx, env, conf);
         }
     }
     

Modified: webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c Mon Dec 12 22:36:46 2005
@@ -55,7 +55,7 @@
                                    axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_op_ctx_init(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
-    struct axis2_engine_config *engine_config);
+    struct axis2_conf *conf);
 axis2_op_t* AXIS2_CALL axis2_op_ctx_getAxisOperation(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
 struct axis2_svc_ctx * AXIS2_CALL axis2_op_ctx_get_parent(struct axis2_op_ctx *op_ctx, 
@@ -203,7 +203,7 @@
 /**
  * The method is used to do the intialization of the axis2_op_ctx
  */
-axis2_status_t AXIS2_CALL axis2_op_ctx_init(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config)
+axis2_status_t AXIS2_CALL axis2_op_ctx_init(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_conf *conf)
 {
     axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     axis2_hash_index_t *hi = NULL;
@@ -222,7 +222,7 @@
         
         if (svc_name)
         {
-            svc = AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, svc_name);
+            svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name);
             
             if (svc)
             {
@@ -241,7 +241,7 @@
         if (ctx)
         {
             axis2_msg_ctx_t *msg_ctx = (axis2_msg_ctx_t*)ctx;
-            AXIS2_MSG_CTX_INIT(msg_ctx, env, engine_config);
+            AXIS2_MSG_CTX_INIT(msg_ctx, env, conf);
         }
     }
     

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c Mon Dec 12 22:36:46 2005
@@ -45,7 +45,7 @@
                                             axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_svc_ctx_init(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env,
-                                            axis2_engine_config_t *engine_config);
+                                            axis2_conf_t *conf);
 axis2_char_t* AXIS2_CALL axis2_svc_ctx_get_svc_id(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env);
 axis2_svc_t* AXIS2_CALL axis2_svc_ctx_get_svc(struct axis2_svc_ctx *svc_ctx, 
@@ -170,7 +170,7 @@
  */
 axis2_status_t AXIS2_CALL axis2_svc_ctx_init(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env,
-                    axis2_engine_config_t *engine_config) 
+                    axis2_conf_t *conf) 
 {
     axis2_svc_ctx_impl_t *svc_ctx_impl = NULL;
     
@@ -181,7 +181,7 @@
     if (svc_ctx_impl->svc_qname)
     {
         axis2_char_t *svc_name = AXIS2_QNAME_GET_LOCALPART(svc_ctx_impl->svc_qname, env);
-        svc_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, svc_name);
+        svc_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name);
     }
     
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c Mon Dec 12 22:36:46 2005
@@ -47,7 +47,7 @@
                                    axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_svc_grp_ctx_init(struct axis2_svc_grp_ctx *svc_grp_ctx, 
                                             axis2_env_t **env,
-                                            axis2_engine_config_t *engine_config);
+                                            axis2_conf_t *conf);
 axis2_char_t* AXIS2_CALL axis2_svc_grp_ctx_get_id(struct axis2_svc_grp_ctx *svc_grp_ctx, 
                         axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_svc_grp_ctx_set_id(struct axis2_svc_grp_ctx *svc_grp_ctx, 
@@ -194,7 +194,7 @@
  */
 axis2_status_t AXIS2_CALL axis2_svc_grp_ctx_init(struct axis2_svc_grp_ctx *svc_grp_ctx, 
                                             axis2_env_t **env,
-                    axis2_engine_config_t *engine_config) 
+                    axis2_conf_t *conf) 
 {
     axis2_svc_grp_ctx_impl_t *svc_grp_ctx_impl = NULL;
     
@@ -204,7 +204,7 @@
 
     if (svc_grp_ctx_impl->svc_grp_name)
     {        
-        svc_grp_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(engine_config, env, svc_grp_ctx_impl->svc_grp_name);
+        svc_grp_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, svc_grp_ctx_impl->svc_grp_name);
     }
     
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/modules/core/description/src/module_desc.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/module_desc.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/module_desc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/module_desc.c Mon Dec 12 22:36:46 2005
@@ -26,7 +26,7 @@
     
     axis2_qname_t *qname;
     
-    axis2_engine_config_t *parent;
+    axis2_conf_t *parent;
     
     /** 
      * To store module opeartions , which are suppose to be added to a service 
@@ -98,14 +98,14 @@
 axis2_module_desc_get_ops (axis2_module_desc_t *module_desc,
                                     axis2_env_t **env);
 
-axis2_engine_config_t * AXIS2_CALL
+axis2_conf_t * AXIS2_CALL
 axis2_module_desc_get_parent (axis2_module_desc_t *module_desc,
                                 axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
 axis2_module_desc_set_parent (axis2_module_desc_t *module_desc,
                                 axis2_env_t **env,
-                                axis2_engine_config_t *parent);
+                                axis2_conf_t *parent);
 
 axis2_status_t AXIS2_CALL
 axis2_module_desc_add_param(axis2_module_desc_t *module_desc,
@@ -453,7 +453,7 @@
     return AXIS2_INTF_TO_IMPL(module_desc)->ops;
 }
 
-axis2_engine_config_t * AXIS2_CALL
+axis2_conf_t * AXIS2_CALL
 axis2_module_desc_get_parent (axis2_module_desc_t *module_desc,
                                 axis2_env_t **env)
 {
@@ -464,7 +464,7 @@
 axis2_status_t AXIS2_CALL
 axis2_module_desc_set_parent (axis2_module_desc_t *module_desc,
                                 axis2_env_t **env,
-                                axis2_engine_config_t *parent)
+                                axis2_conf_t *parent)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, parent, AXIS2_FAILURE);

Modified: webservices/axis2/trunk/c/modules/core/description/src/svc.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/svc.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/svc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/svc.c Mon Dec 12 22:36:46 2005
@@ -91,13 +91,13 @@
 axis2_svc_engage_module(axis2_svc_t *svc,
                             axis2_env_t **env,
                             struct axis2_module_desc * moduleref,
-                            struct axis2_engine_config * axis2_config);
+                            struct axis2_conf * axis2_config);
 
 axis2_status_t AXIS2_CALL
 axis2_svc_add_module_ops(axis2_svc_t *svc,
                             axis2_env_t **env,
                             struct axis2_module_desc * module,
-                            struct axis2_engine_config * axis2_config);
+                            struct axis2_conf * axis2_config);
                                 
 axis2_status_t AXIS2_CALL
 axis2_svc_add_to_engaged_module_list(axis2_svc_t *svc,
@@ -759,7 +759,7 @@
 {
     axis2_bool_t locked = AXIS2_FALSE;
     axis2_param_t *param_l = NULL;
-    struct axis2_engine_config *engine_config_l = NULL;
+    struct axis2_conf *conf_l = NULL;
     struct axis2_svc_grp *parent = NULL;
     axis2_bool_t ret = AXIS2_FALSE;
     
@@ -774,12 +774,12 @@
         return AXIS2_FALSE;
     }
     
-    engine_config_l = AXIS2_SVC_GRP_GET_AXIS_DESC(parent, env);
-    if(NULL == engine_config_l)
+    conf_l = AXIS2_SVC_GRP_GET_AXIS_DESC(parent, env);
+    if(NULL == conf_l)
     {
         return AXIS2_FALSE;
     }
-    locked =  AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(engine_config_l, env, param_name);
+    locked =  AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(conf_l, env, param_name);
     
     if(AXIS2_TRUE == locked)
     {
@@ -820,7 +820,7 @@
 axis2_svc_engage_module(axis2_svc_t *svc,
                             axis2_env_t **env,
                             struct axis2_module_desc * moduleref,
-                            struct axis2_engine_config * axis2_config)
+                            struct axis2_conf * axis2_config)
 {
     struct axis2_module_desc * modu = NULL;
     axis2_array_list_t *collection_module = NULL;
@@ -876,7 +876,7 @@
 axis2_svc_add_module_ops(axis2_svc_t *svc,
                             axis2_env_t **env,
                             struct axis2_module_desc * module_desc,
-                            struct axis2_engine_config * axis2_config) 
+                            struct axis2_conf * axis2_config) 
 {
     axis2_hash_t * map = NULL;
     axis2_hash_index_t *index = NULL;

Modified: webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c Mon Dec 12 22:36:46 2005
@@ -28,7 +28,7 @@
     /** to store service Group modules name */
     axis2_array_list_t *modules;
     /** to store module ref at deploy time parsing */
-    struct axis2_engine_config *parent; 
+    struct axis2_conf *parent; 
     axis2_array_list_t *module_list;
     
 	
@@ -95,14 +95,14 @@
                                 axis2_env_t **env,
                                 axis2_qname_t *module_qname);                                
 
-struct axis2_engine_config * AXIS2_CALL
+struct axis2_conf * AXIS2_CALL
 axis2_svc_grp_get_parent(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_set_parent(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env,
-                            struct axis2_engine_config *parent);
+                            struct axis2_conf *parent);
 
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_engage_module_to_grp(axis2_svc_grp_t *svc_grp,
@@ -113,14 +113,14 @@
 axis2_svc_grp_get_svc_grp_modules(axis2_svc_grp_t *svc_grp,
                                     axis2_env_t **env);
 
-struct axis2_engine_config *AXIS2_CALL
+struct axis2_conf *AXIS2_CALL
 axis2_svc_grp_get_axis_desc(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_set_axis_desc(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env,
-                            struct axis2_engine_config *axis2_desc);
+                            struct axis2_conf *axis2_desc);
 
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_add_moduleref(axis2_svc_grp_t *svc_grp,
@@ -218,17 +218,17 @@
 }
 
 axis2_svc_grp_t * AXIS2_CALL 
-axis2_svc_grp_create_with_engine_config (axis2_env_t **env,
-                                         struct axis2_engine_config *engine_config)
+axis2_svc_grp_create_with_conf (axis2_env_t **env,
+                                         struct axis2_conf *conf)
 {
     axis2_svc_grp_impl_t *svc_grp_impl = NULL;
     
     AXIS2_ENV_CHECK(env, NULL);
-    AXIS2_PARAM_CHECK((*env)->error, engine_config, NULL);
+    AXIS2_PARAM_CHECK((*env)->error, conf, NULL);
     
     svc_grp_impl = (axis2_svc_grp_impl_t *) axis2_svc_grp_create(env);
     if(NULL != svc_grp_impl)
-        svc_grp_impl->parent = engine_config;
+        svc_grp_impl->parent = conf;
     
     return &(svc_grp_impl->svc_grp);
         
@@ -526,7 +526,7 @@
                                 axis2_char_t *param_name) 
 {
     axis2_bool_t locked = AXIS2_FALSE;
-    struct axis2_engine_config *parent = NULL;
+    struct axis2_conf *parent = NULL;
     axis2_param_t *param = NULL;
     axis2_bool_t ret = AXIS2_FALSE;
     
@@ -567,7 +567,7 @@
         module_qname);
 }
 
-struct axis2_engine_config * AXIS2_CALL
+struct axis2_conf * AXIS2_CALL
 axis2_svc_grp_get_parent(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env) 
 {
@@ -579,7 +579,7 @@
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_set_parent(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env,
-                            struct axis2_engine_config *parent) 
+                            struct axis2_conf *parent) 
 {
     axis2_svc_grp_impl_t *svc_grp_impl = NULL;
     
@@ -678,7 +678,7 @@
     return AXIS2_INTF_TO_IMPL(svc_grp)->modules;
 }
 
-struct axis2_engine_config *AXIS2_CALL
+struct axis2_conf *AXIS2_CALL
 axis2_svc_grp_get_axis_desc(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env) 
 {
@@ -690,7 +690,7 @@
 axis2_status_t AXIS2_CALL
 axis2_svc_grp_set_axis_desc(axis2_svc_grp_t *svc_grp,
                             axis2_env_t **env,
-                            struct axis2_engine_config *axis2_desc) 
+                            struct axis2_conf *axis2_desc) 
 {
     axis2_svc_grp_impl_t *svc_grp_impl = NULL;
     

Modified: webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c (original)
+++ webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c Mon Dec 12 22:36:46 2005
@@ -119,13 +119,13 @@
                     conf_ctx = AXIS2_MSG_CTX_GET_CONF_CTX(msg_ctx, env);
                     if (conf_ctx)
                     {
-                        axis2_engine_config_t *engine_config = NULL;
-                        engine_config = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
-                        if (engine_config)
+                        axis2_conf_t *conf = NULL;
+                        conf = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
+                        if (conf)
                         {
                             axis2_svc_t *svc = NULL;
                             axis2_qname_t *qname = axis2_qname_create(env, url_tokens[0], NULL, NULL);
-                            svc = AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, AXIS2_QNAME_GET_LOCALPART(qname, env));
+                            svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, AXIS2_QNAME_GET_LOCALPART(qname, env));
                             
                             AXIS2_QNAME_FREE(qname, env);
                             return svc;

Modified: webservices/axis2/trunk/c/modules/core/engine/src/engine.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/engine/src/engine.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/engine/src/engine.c (original)
+++ webservices/axis2/trunk/c/modules/core/engine/src/engine.c Mon Dec 12 22:36:46 2005
@@ -162,7 +162,7 @@
     }
     
     axis2_conf_ctx_t *conf_ctx = NULL;
-    axis2_engine_config_t *engine_config = NULL;
+    axis2_conf_t *conf = NULL;
     /*axis2_array_list_t *global_out_phase = NULL;*/
 
     if (AXIS2_MSG_CTX_IS_PAUSED(msg_ctx, env))
@@ -180,10 +180,10 @@
         conf_ctx = AXIS2_MSG_CTX_GET_CONF_CTX(msg_ctx, env);
         if (conf_ctx)
         {
-            engine_config = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
-            if (engine_config)
+            conf = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
+            if (conf)
             {
-                /*TODO global_out_phase = AXIS2_ENGINE_CONFIG_GET_GLOBAL_OUT_PASES(engine_config, env);
+                /*TODO global_out_phase = AXIS2_ENGINE_CONFIG_GET_GLOBAL_OUT_PASES(conf, env);
                 axis2_engine_invoke_phases(engine, env, global_out_phase, msg_ctx); */
             }
         }
@@ -195,10 +195,10 @@
         conf_ctx = AXIS2_MSG_CTX_GET_CONF_CTX(msg_ctx, env);
         if (conf_ctx)
         {
-            engine_config = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
-            if (engine_config)
+            conf = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
+            if (conf)
             {
-                /*global_out_phase = AXIS2_ENGINE_CONFIG_GET_GLOBAL_OUT_PHASES(engine_config, env);
+                /*global_out_phase = AXIS2_ENGINE_CONFIG_GET_GLOBAL_OUT_PHASES(conf, env);
                 axis2_engine_invoke_phases(engine, env, global_out_phase, msg_ctx);*/
             }
         }
@@ -229,7 +229,7 @@
 {
     axis2_engine_impl_t *engine_impl = NULL;
     axis2_conf_ctx_t *conf_ctx = NULL;
-    axis2_engine_config_t *engine_config = NULL;
+    axis2_conf_t *conf = NULL;
     axis2_op_ctx_t *op_ctx = NULL;
     axis2_op_t *op = NULL;
     axis2_array_list_t *pre_calculated_phases = NULL;
@@ -242,9 +242,9 @@
     
     conf_ctx = AXIS2_MSG_CTX_GET_CONF_CTX(msg_ctx, env);
     
-    engine_config = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
+    conf = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
     
-    pre_calculated_phases = AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(engine_config, env);
+    pre_calculated_phases = AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(conf, env);
     
     if (AXIS2_MSG_CTX_IS_PAUSED(msg_ctx, env))
     {
@@ -368,10 +368,10 @@
         axis2_conf_ctx_t *conf_ctx = AXIS2_MSG_CTX_GET_CONF_CTX(msg_ctx, env);
         if (conf_ctx)
         {
-            axis2_engine_config_t *engine_config = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
-            if (engine_config)
+            axis2_conf_t *conf = AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env);
+            if (conf)
             {
-                axis2_array_list_t *phases = AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(engine_config, env);
+                axis2_array_list_t *phases = AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(conf, env);
                 if (phases)
                 {
                     if (AXIS2_MSG_CTX_IS_PAUSED(msg_ctx, env))
--- webservices/axis2/trunk/c/include/axis2_msg_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_msg_ctx.h Mon Dec 12 22:36:46 2005
@@ -70,7 +70,7 @@
 struct axis2_svc_ctx;
 struct axis2_op_ctx;
 struct axis2_session_ctx;
-struct axis2_engine_config;
+struct axis2_conf;
 struct axis2_soap_envelope;
     
 /** 
@@ -100,7 +100,7 @@
      */
     axis2_status_t (AXIS2_CALL *init)(struct axis2_msg_ctx *msg_ctx, 
                                         axis2_env_t **env, 
-                                        struct axis2_engine_config *engine_config);
+                                        struct axis2_conf *conf);
     
     /**
      * @return
@@ -416,8 +416,8 @@
      * 2. Search in corresponding op if its there
      * 3. Search in module configurations inside corresponding service description if its there
      * 4. Next search in Corresponding Service description if its there
      * 5. Next sercah in module configurations inside engine_config
      * 6. Search in axis2_engine_config_t *for paramters
      * 7. Next AXIS2_CALL get the corresponding module and search for the paramters
      * 8. Search in axis2_handler_desc_t *for the paramter
      * <p/>
@@ -604,7 +604,7 @@
 #define AXIS2_MSG_CTX_GET_PARENT(msg_ctx, env) ((msg_ctx)->ops->get_parent(msg_ctx, env))
 #define AXIS2_MSG_CTX_SET_PARENT(msg_ctx, env, parent) ((msg_ctx)->ops->get_parent(msg_ctx, env, parent))
 #define AXIS2_MSG_CTX_FREE(msg_ctx, env) ((msg_ctx)->ops->free(msg_ctx, env))
-#define AXIS2_MSG_CTX_INIT(msg_ctx, env, engine_config) ((msg_ctx)->ops->init(msg_ctx, env, engine_config))
+#define AXIS2_MSG_CTX_INIT(msg_ctx, env, conf) ((msg_ctx)->ops->init(msg_ctx, env, conf))
 
 #define AXIS2_MSG_CTX_GET_FAULT_TO(msg_ctx, env) ((msg_ctx)->ops->get_fault_to(msg_ctx, env))
 /*
@@ -416,8 +416,8 @@
      * 3. Search in module configurations inside corresponding service description if its there
      * 4. Next search in Corresponding Service description if its there
-     * 5. Next sercah in module configurations inside engine_config
-     * 6. Search in axis2_engine_config_t *for paramters
+     * 5. Next sercah in module configurations inside conf
+     * 6. Search in axis2_conf_t *for paramters
      * 7. Next AXIS2_CALL get the corresponding module and search for the paramters
      * 8. Search in axis2_handler_desc_t *for the paramter

Modified: webservices/axis2/trunk/c/include/axis2_op_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_op_ctx.h?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c Mon Dec 12 22:36:46 2005
@@ -18,7 +18,7 @@
 #include <axis2_op.h>
 #include <axis2_svc.h>
 #include <axis2_svc_grp.h>
-#include <axis2_engine_config.h>
+#include <axis2_conf.h>
 
 typedef struct axis2_msg_ctx_impl axis2_msg_ctx_impl_t;
 
@@ -129,7 +129,7 @@
 axis2_status_t AXIS2_CALL
 axis2_msg_ctx_init(struct axis2_msg_ctx *msg_ctx, 
                     axis2_env_t **env, 
-                    struct axis2_engine_config *engine_config);
+                    struct axis2_conf *conf);
 axis2_endpoint_ref_t *AXIS2_CALL 
 axis2_msg_ctx_get_fault_to(struct axis2_msg_ctx *msg_ctx, 
                             axis2_env_t **env);
@@ -727,33 +727,33 @@
  */
 axis2_status_t AXIS2_CALL axis2_msg_ctx_init(struct axis2_msg_ctx *msg_ctx, 
                     axis2_env_t **env, 
-                    struct axis2_engine_config *engine_config)
+                    struct axis2_conf *conf)
 {
     axis2_msg_ctx_impl_t *msg_ctx_impl = NULL;
     
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, engine_config, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, conf, AXIS2_FAILURE);
     
     msg_ctx_impl = AXIS2_INTF_TO_IMPL(msg_ctx);
     
     /*if (msg_ctx_impl->transport_in_desc_qname)
     {
-        msg_ctx_impl->transport_in_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(engine_config, env, msg_ctx_impl->transport_in_desc_qname);
+        msg_ctx_impl->transport_in_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_in_desc_qname);
     }*/
     
     /*if (msg_ctx_impl->transport_out_desc_qname)
     {
-        msg_ctx_impl->transport_out_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(engine_config, env, msg_ctx_impl->transport_out_desc_qname);
+        msg_ctx_impl->transport_out_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_out_desc_qname);
     }*/
     
     if (msg_ctx_impl->svc_grp_id)
     {
-        /*msg_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(engine_config, env, msg_ctx_impl->svc_grp_id);*/
+        /*msg_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, msg_ctx_impl->svc_grp_id);*/
     }
     
     if (msg_ctx_impl->svc_qname)
     {
-        /*msg_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, AXIS2_QNAME_GET_LOCALPART(msg_ctx_impl->svc_qname, env));*/
+        /*msg_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, AXIS2_QNAME_GET_LOCALPART(msg_ctx_impl->svc_qname, env));*/
     }
     
     if (msg_ctx_impl->op_qname)
@@ -1462,8 +1462,8 @@
     
     if (msg_ctx_impl->conf_ctx) 
     {
-        /*axis2_engine_config_t *engine_config = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);
-        param = AXIS2_ENGINE_CONFIG_GET_PARAM(engine_config, env, key);*/
+        /*axis2_conf_t *conf = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);
+        param = AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, key);*/
     }
     
     return param;
@@ -1477,8 +1477,8 @@
  * 2. Search in corresponding op if its there
  * 3. Search in module configurations inside corresponding service description if its there
  * 4. Next search in Corresponding Service description if its there
  * 5. Next sercah in module configurations inside engine_config
  * 6. Search in axis2_engine_config_t *for paramters
  * 7. Next AXIS2_CALL axis2_msg_ctx_get the corresponding module and search for the paramters
  * 8. Search in axis2_handler_desc_t *for the paramter
  * <p/>
@@ -1502,7 +1502,7 @@
     /*axis2_module_config_t *module_config = NULL;*/
     /*axis2_module_t *module = NULL;*/
     axis2_qname_t *qname = NULL;
-    axis2_engine_config_t *engine_config = NULL;
+    axis2_conf_t *conf = NULL;
     
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, module_name, AXIS2_FAILURE);
@@ -1577,10 +1577,10 @@
         }*/
     }
     
-    /*engine_config = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);*/
-    if (engine_config)
+    /*conf = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);*/
+    if (conf)
     {
-        /*module_config = AXIS2_ENGINE_CONFIG_GET_MODULE_CONFIG(engine_config, env, qname);*/
+        /*module_config = AXIS2_ENGINE_CONFIG_GET_MODULE_CONFIG(conf, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
     }    
     
@@ -1593,7 +1593,7 @@
         } 
         else 
         {
-            param = AXIS2_ENGINE_CONFIG_GET_PARAM(engine_config, env, key);
+            param = AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, key);
             if (param)
             {
                 return param;
@@ -1601,9 +1601,9 @@
         }
     }*/
     
-    if (engine_config)
+    if (conf)
     {
-        /*module = AXIS2_ENGINE_CONFIG_GET_MODULE(engine_config, env, qname);*/
+        /*module = AXIS2_ENGINE_CONFIG_GET_MODULE(conf, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
     }
     
@@ -1477,8 +1477,8 @@
  * 3. Search in module configurations inside corresponding service description if its there
  * 4. Next search in Corresponding Service description if its there
- * 5. Next sercah in module configurations inside engine_config
- * 6. Search in axis2_engine_config_t *for paramters
+ * 5. Next sercah in module configurations inside conf
+ * 6. Search in axis2_conf_t *for paramters
  * 7. Next AXIS2_CALL axis2_msg_ctx_get the corresponding module and search for the paramters
  * 8. Search in axis2_handler_desc_t *for the paramter

Modified: webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c?rev=356490&r1=356489&r2=356490&view=diff
==============================================================================